/**
 * This class represents an entry in a dictionary of synonyms and antonyms a window in which the results of a search are displayed
 * 
 * @author Sandino Vargas-Perez
 * @version 31 MAy 2020
 *
 */
public class DictionaryEntry {
	
	private String word;
	private String synonyms;
	private String antonyms;
	
	public DictionaryEntry(String w) {
		this.word = w;
		synonyms = null;
		antonyms = null;
	}
	
	/**
	 * Returns the word in this entry
	 * @return the word
	 */
	public String getWord() {
		return word;
	}

	/**
	 * Returns the list of synonyms as a String
	 * @return the synonyms
	 */
	public String getSynonyms() {
		return synonyms;
	}
	
	/**
	 * Returns the synonyms as an array of synonym words
	 * @return array of string words
	 */
	public String[] getSynonymsAsArray() {
		if(synonyms != null)
			return synonyms.split(",");
		else
			return null;
	}

	/**
	 * Returns the list of antonyms as a String
	 * @return the antonyms
	 */
	public String getAntonyms() {
		return antonyms;
	}

	/**
	 * Returns the antonyms as an array of antonym words
	 * @return array of string words
	 */
	public String[] getAntonymsAsArray() {
		if(antonyms != null)
			return antonyms.split(",");
		else
			return null;
	}
	
	/**
	 * Add a list of synonyms as a single string
	 * @param synonyms the synonyms to set
	 */
	public void setSynonyms(String synonyms) {
		this.synonyms = synonyms;
	}

	/**
	 * Add a list of antonyms as a single string
	 * @param antonyms the antonyms to set
	 */
	public void setAntonyms(String antonyms) {
		this.antonyms = antonyms;
	}
}
