import java.io.IOException;
import java.io.BufferedReader;
import java.io.FileReader;

/**
 * This class contains code to read line from a file.
 * 
 * @author Sandino Vargas-Perez
 * @author Based of WordCount by Dr. Alyce Brady
 * @version 31 MAy 2020
 */
public abstract class Engine {
	protected String filename;
	protected BufferedReader reader;
	protected Results display;

	/**
	 * Constructs an object that can read words from a file.
	 * 
	 * @param filename the name of the file to open for reading
	 */
	public Engine(String fName) {
		this.filename = fName;

		try {
			this.reader = new BufferedReader(new FileReader(filename));
		} catch (IOException e) {
			System.err.println("Cannot open file " + filename + " for reading");
		}
		this.display = new Results(this);
	}

	/**
	 * Reads from a file and populates a data structure with a word-(syns and ants)
	 * pairs
	 */
	protected abstract void populateDictionary();

	/**
	 * Searches for a word in the dictionary and displays synonyms and antonyms if
	 * the word has them.
	 * 
	 * @param word to be searched
	 */
	public abstract void search(String word);

	/**
	 * Checks if the dictionary contains the given word
	 * 
	 * @param word
	 * @return true if word (key) is in dictionary, false otherwise
	 */
	public abstract boolean contains(String word);
}
